####
kakaocert.py
####
kakaocert 2.50.0

Kakaocert API for Python.

.. image:: https://api.travis-ci.org/linkhub-sdk/Kakaocert.py.svg?branch=master
        :target: https://travis-ci.org/linkhub-sdk/Kakaocert.py

* requirements

  * Python 2.6+
  * linkhub

************
Installation
************

Install via pip:

::

    $ pip install Kakaocert

Install from source:

::

    $ git clone git://github.com/linkhub-sdk/Kakaocert.py.git
    $ cd Kakaocert.py
    $ python setup.py install

사이트
-------------------------------
`Pypi <https://pypi.python.org/pypi/popbill/>`_,
`링크허브(Linkhub) <https://www.linkhub.co.kr/>`_,
`Kakaocert <https://www.Kakaocert.com/>`_,
